@@ -5,6 +5,16 @@ Command::Command()
     d_action(FROM_HOME),
     d_parent(0)
 {
+    ArgConfig &argConfig = ArgConfig::instance();
+
+    if (string value; argConfig.option(&value, "homedir-char"))
+    {
+        d_homedirChar = value[0];
+        if ("0123456789/"s.find(d_homedirChar) != string::npos)
+            throw Exception{ 1 } << "Character `" << value[0] <<
+                                    "' cannot be used as homedir-character";
+    }
+
     concatArgs();
 
     determineAction();
@@ -13,7 +23,7 @@ Command::Command()
 
     // When are the elements of the first argument changed into initial chars
     // of directory elements?
-    // 1. if there is only one command line argument 
+    // 1. if there is only one command line argument
     // 2. if the first argument is not to be interpreted as a name by itself
     // 3. if there's only one argument
     // Can't 2 and 3 be combined to: size() == 1 ?
@@ -22,7 +32,7 @@ Command::Command()
     if (size() == 1)
     {
         for_each(
-            front().begin() + 1, front().end(), 
+            front().begin() + 1, front().end(),
             [&](char ch)
             {
                 this->push_back(string(1, ch));
@@ -40,6 +50,3 @@ Command::Command()
         cerr << endl;
     }
 }
-
-
-
